!> Enforce the problem's boundary conditions on a padded domain.
!! Given valid data \f$ \vec{u}\left(x_i, t\right) \f$ for
!! \f$ i\in\left\{0,\ldots,n\right\} \f$, modify storage locations
!! <tt>u(-padsize:0)</tt> and <tt>u(n,n+padsize)</tt> so that
!! the problem's boundary conditions are enforced.
!!
!! @param u       \f$u\f$
!! @param x       \f$x\f$
!! @param t       \f$t\f$
!! @param n       Grid size.  Note that array size differs from \c n.
!! @param padsize Amount of padding added to the domain <tt>0:n</tt>.
SUBROUTINE problem_bc(u, x, t, n, padsize)

  INTEGER, PARAMETER :: neqn = 3
  INTEGER, PARAMETER :: dp = KIND(1.d0)

  INTEGER, INTENT(IN)          :: n, padsize
  REAL(KIND = dp), INTENT(IN)  :: x(0:n), t
  REAL(KIND = dp), INTENT(OUT) :: u(neqn,-padsize:n+padsize)

  u(:, -padsize:0) = SIN(2*pi*t)             ! Sinusoidal left boundary
  u(:, n+1:n+padsize) = -u(:, n-padsize:n-1) ! Reflective right boundary

END SUBROUTINE problem_bc
